@@ -216,7 +216,7 @@ RawImage DngDecoder::decodeRawInternal() {
           if (bps != 8 && bps != 16)
             big_endian = true;
           try {
-            readUncompressedRaw(in, size, pos, width*bps / 8, bps, big_endian);
+            readUncompressedRaw(in, size, pos, mRaw->getCpp()* width * bps / 8, bps, big_endian ? BitOrder_Jpeg : BitOrder_Plain);
           } catch(IOException &ex) {
             if (i > 0)
               mRaw->setError(ex.what());
@@ -379,6 +379,21 @@ RawImage DngDecoder::decodeRawInternal() {
   if (mRaw->dim.area() <= 0)
     ThrowRDE("DNG Decoder: No image left after crop");
 
+  // Apply stage 1 opcodes
+  if (applyStage1DngOpcodes) {
+    if (raw->hasEntry(OPCODELIST1))
+    {
+      // Apply stage 1 codes
+      try{
+        DngOpcodes codes(raw->getEntry(OPCODELIST1));
+        mRaw = codes.applyOpCodes(mRaw);
+      } catch (RawDecoderException &e) {
+        // We push back errors from the opcode parser, since the image may still be usable
+        mRaw->setError(e.what());
+      }
+    }
+  }
+
   // Linearization
   if (raw->hasEntry(LINEARIZATIONTABLE)) {
     const ushort16* intable = raw->getEntry(LINEARIZATIONTABLE)->getShortArray();
